@@ -29,21 +29,6 @@ class Analysis(Abstract):
       eprint('ERROR: {}'.format(error))
       return {'error': True, 'msg': error}
 
-  def get_instances(self, payload={}, verify=True):
-    '''Get available instances for analyses'''
-    try:
-      response = requests.post(
-        '{}get_instances'.format(self.endpoint),
-        data=json.dumps(payload),
-        headers=self.headers,
-        params=self.payload,
-        verify=verify,
-      )
-      return self._parse_response(response)
-    except requests.exceptions.RequestException as error:
-      eprint('ERROR: {}'.format(error))
-      return {'error': True, 'msg': error}
-
   def reanalyze(self, payload={}, verify=True):
     '''Restart analysis'''
     try:
